@@ -236,6 +236,7 @@ class View(Object):
 		return self.render(request, f"w3bsite/classes/apps/defaults/html/404.html", template_data)
 	def _500(self, request, template_data=None, error=None):
 		if template_data == None: template_data = self.template_data
+		if template_data == None: template_data = {}
 		info = utils.catch_error(error)
 		traceback, debug = None, False
 		if not dev0s.env.get("PRODUCTION", format=bool, default=True) or dev0s.env.get("DEBUG", format=bool, default=False):
@@ -250,8 +251,7 @@ class View(Object):
 	# append template data.
 	def template(self, dictionary={}, old=None):
 		if old == None: old = self.template_data
-		if dictionary == None:
-			return old
+		if dictionary == None or dictionary == "None": return old
 		return utils.template(old=old, new=dictionary)
 
 	# the view function.
